@@ -5,9 +5,6 @@ import logging
 import time
 import json
 import re
-import cv2
-import numpy as np
-import urllib
 from requests_toolbelt import MultipartEncoder
 from bs4 import BeautifulSoup
 try:
@@ -20,13 +17,15 @@ except ModuleNotFoundError:
     from . import privacy_level
     from . import like_action
 
-def letter_adder(string:str, num:int):
-    if ord(string[1]) + num%26 >= ord('z'):
-        string = chr(ord(string[0])+1) + chr(ord(string[1])+ num - 26)
+
+def letter_adder(string: str, num: int):
+    if ord(string[1]) + num % 26 >= ord('z'):
+        string = chr(ord(string[0])+1) + chr(ord(string[1]) + num - 26)
     else:
         string = string[0] + chr(ord(string[1]) + num)
     return string
 
+
 class API:
     '''
     FB post structure:
@@ -36,14 +35,15 @@ class API:
             |
             --reply
     '''
+
     def __init__(self):
         headers = {
-            'Host': 'mbasic.facebook.com',
+            'Host': 'm.facebook.com',
             'User-Agent': 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:84.0) Gecko/20100101 Firefox/84.0',
             'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
             'Accept-Language': 'zh-TW,zh;q=0.8,en-US;q=0.5,en;q=0.3',
             'Content-Type': 'application/x-www-form-urlencoded',
-            'Origin': 'https://mbasic.facebook.com',
+            'Origin': 'https://m.facebook.com',
             'DNT': '1',
             'Connection': 'keep-alive',
             'Upgrade-Insecure-Requests': '1',
@@ -51,7 +51,8 @@ class API:
         self.session = requests.session()
         self.session.headers.update(headers)
         self.login_check = False
-    def login(self, email:str, password:str):
+
+    def login(self, email: str, password: str):
         # get input field
         self.session.cookies.clear()
         if os.path.isfile(email+'.cookie'):
@@ -59,102 +60,104 @@ class API:
             try:
                 self.user_id = self.session.cookies.get_dict()['c_user']
             except:
-                logging.error('Cookies is invalid, remove cookies and try again')
+                logging.error(
+                    'Cookies is invalid, remove cookies and try again')
                 return
         else:
-            url = 'https://mbasic.facebook.com/login'
+            url = 'https://m.facebook.com/login'
             req = self.session.get(url)
-            soup = BeautifulSoup(req.text,'lxml')
-            all_input_data = soup.find('form').findAll('input', {'type':'hidden'})
+            soup = BeautifulSoup(req.text, 'lxml')
+            all_input_data = soup.find('form').findAll(
+                'input', {'type': 'hidden'})
             data = {}
             for input_data in all_input_data:
                 data[input_data.get('name')] = input_data.get('value')
             # input email and password
             data['email'] = email
             data['pass'] = password
-            #login
-            login_url = 'https://mbasic.facebook.com/login'
-            req = self.session.post(login_url,data=data)
+            # login
+            login_url = 'https://m.facebook.com/login'
+            req = self.session.post(login_url, data=data)
         self.user_id = self.session.cookies.get_dict()['c_user']
         # get hidden input data
-        url = 'https://mbasic.facebook.com/'
+        url = 'https://m.facebook.com/'
         req = self.session.get(url)
         soup = BeautifulSoup(req.text, 'lxml')
         try:
-            self.fb_dtsg = soup.find('input', {'name':'fb_dtsg'}).get('value')
+            self.fb_dtsg = soup.find('input', {'name': 'fb_dtsg'}).get('value')
         except Exception as e:
             logging.debug(e)
             logging.error('username or password is invalid')
             return False
-        
+
         self.login_check = True
         self._save_cookies(email+'.cookie')
         self.send_msg_data = {
-                                'fb_dtsg': self.fb_dtsg,
-                                'body':'',
-                                'send':'傳送',
-                                'wwwupp':'C3'
-                              }
+            'fb_dtsg': self.fb_dtsg,
+            'body': '',
+            'send': '傳送',
+            'wwwupp': 'C3'
+        }
         self.post_data_template = {
-                                    'fb_dtsg': self.fb_dtsg,
-                                    'target': self.user_id,
-                                    'c_src': 'feed',
-                                    'cwevent': 'composer_entry',
-                                    'referrer': 'feed',
-                                    'ctype': 'inline',
-                                    'cver': 'amber',
-                                    'rst_icv': None,
-                                    'view_post': 'view_post',
-                                  }
-    def _save_cookies(self, filename:str):
+            'fb_dtsg': self.fb_dtsg,
+            'target': self.user_id,
+            'c_src': 'feed',
+            'cwevent': 'composer_entry',
+            'referrer': 'feed',
+            'ctype': 'inline',
+            'cver': 'amber',
+            'rst_icv': None,
+            'view_post': 'view_post',
+        }
+
+    def _save_cookies(self, filename: str):
         with open(filename, 'wb') as f:
             pickle.dump(self.session.cookies, f)
 
-    def _load_cookies(self, filename:str):
-        with open(filename,'rb') as f:
+    def _load_cookies(self, filename: str):
+        with open(filename, 'rb') as f:
             self.session.cookies.update(pickle.load(f))
-    
+
     # post methods
-    def get_post(self, post_id:str, group_id=None):
+    def get_post(self, post_id: str, group_id=None):
         if not self.login_check:
             logging.error('You should login first')
             return
         url = 'https://mbasic.facebook.com/story.php?' + \
-              'story_fbid=%s&id=1'%str(post_id)
+              'story_fbid=%s&id=1' % str(post_id)
         if group_id:
-            url = 'https://mbasic.facebook.com/groups/%s?'%str(group_id) + \
-                  'view=permalink&id=%s'%str(post_id)
+            url = 'https://mbasic.facebook.com/groups/%s?' % str(group_id) + \
+                  'view=permalink&id=%s' % str(post_id)
         req = self.session.get(url)
-        soup = BeautifulSoup(req.text,'lxml')
-        post_content = soup.find('div',id='m_story_permalink_view')
+        soup = BeautifulSoup(req.text, 'lxml')
+        post_content = soup.find('div', id='m_story_permalink_view')
         author = post_content.find('h3', recursive=True).text
-        content = str(post_content.find('div', {'data-ft':'{"tn":"*s"}'}))
+        content = str(post_content.find('div', {'data-ft': '{"tn":"*s"}'}))
         content = content.replace('<br/> ', '\n')
         content = content.replace('<br/>', '\n')
         content = re.sub('<[^>]+> ', '', content)
         content = re.sub('<[^>]+>', '', content)
         time = post_content.find('footer').find('abbr').text
-        post_image = post_content.find('div', {'data-ft':'{"tn":"H"}'})
+        post_image = post_content.find('div', {'data-ft': '{"tn":"H"}'})
         images = []
         link = None
         if post_image:
             for img_src in post_image.find_all('img', class_='s'):
                 src = img_src.get('src')
-                response = urllib.request.urlopen(src)
-                img = np.asarray(bytearray(response.read()), dtype="uint8")
-                img = cv2.imdecode(img, cv2.IMREAD_COLOR)
-                images.append(img)
-            link = post_image.find('a', id='u_0_2')
+                images.append(src)
+            link = post_image.find('a')
             if link:
                 link = link.get('href')
         post_info = data_type.PostInfo(post_id,
+                                       url,
                                        author,
                                        content,
                                        time,
                                        images,
                                        link)
         if not post_content:
-            logging.error('This post is not supported or you don\'t have acess authority')
+            logging.error(
+                'This post is not supported or you don\'t have acess authority')
         return post_info
 
     def like_post(self, post_id, action=like_action.LIKE):
@@ -165,88 +168,93 @@ class API:
         if action > 6 or action < 0:
             logging.error('This action is not supported')
             return
-        url = 'https://mbasic.facebook.com/reactions/picker/?ft_id=' + str(post_id)
+        url = 'https://mbasic.facebook.com/reactions/picker/?ft_id=' + \
+            str(post_id)
         req = self.session.get(url)
         try:
             soup = BeautifulSoup(req.text, 'lxml')
-            root = soup.find('div', id='root').find('table', role='presentation')
-            action_href = [a.get('href')  for a in root.findAll('a')][:-1]
+            root = soup.find('div', id='root').find(
+                'table', role='presentation')
+            action_href = [a.get('href') for a in root.findAll('a')][:-1]
             like_url = 'https://mbasic.facebook.com' + action_href[action]
             self.session.get(like_url)
         except Exception:
             logging.error('You don\'t have access authority')
 
-    def get_user_post_list(self, user_id, num=10):
+    def get_user_post_list(self, user_id):
         if not self.login_check:
             logging.error('You should login first')
             return
-        url = 'https://mbasic.facebook.com/profile/timeline/stream/?' + \
-              'end_time=%s&'%str(time.time()) + \
-              'profile_id=%s'%str(user_id)
-        posts_id = []
-        while len(posts_id) < num:
+        url = 'https://m.facebook.com/%s?tsid=1' % str(user_id)
+        while True:
             req = self.session.get(url)
             soup = BeautifulSoup(req.text, 'lxml')
             posts = soup.find('section').findAll('article', recursive=False)
             for post in posts:
                 data = json.loads(post.get('data-ft'))
+                if 'mf_story_key' not in data:
+                    continue
                 post_id = data['mf_story_key']
-                posts_id.append(post_id)
-                if len(posts_id) >= num:
-                    break
-            if len(posts_id) >= num:
-                    break
-            next_href = soup.find('div', id='u_0_0').find('a').get('href')
-            url = 'https://mbasic.facebook.com' + next_href
-        return posts_id
+            yield post_id
+            next_page_div = soup.find('section').next_sibling
+            if next_page_div.get('id'):
+                next_href = next_page_div.find('a').get('href')
+                url = 'https://m.facebook.com' + next_href
+            else:
+                break
 
-    def get_group_post_list(self, group_id, num=10):
+    def get_group_post_list(self, group_id):
         if not self.login_check:
             logging.error('You should login first')
             return
-        url = 'https://mbasic.facebook.com/%s'%str(group_id)
-        posts_id = []
-        while len(posts_id) < num:
+        url = 'https://m.facebook.com/groups/%s' % str(group_id)
+        while True:
             req = self.session.get(url)
             soup = BeautifulSoup(req.text, 'lxml')
-            soup = soup.find('div',id='m_group_stories_container')
+            soup = soup.find('div', id='m_group_stories_container')
             posts = soup.find('section').findAll('article', recursive=False)
             for post in posts:
                 data = json.loads(post.get('data-ft'))
+                if 'mf_story_key' not in data:
+                    continue
                 post_id = data['mf_story_key']
-                posts_id.append(post_id)
-                if len(posts_id) >= num:
-                    break
-            if len(posts_id) >= num:
-                    break
-            next_href = soup.find('section').next_sibling.find('a').get('href')
-            url = 'https://mbasic.facebook.com' + next_href
-        return posts_id
-    
-    def get_fanpage_post_list(self, fanpage_id, num=10):
-        if not self.login_check:
-            logging.error('You should login first')
-            return
-        url = 'https://mbasic.facebook.com/%s'%str(fanpage_id)
-        posts_id = []
-        while len(posts_id) < num:
-            req = self.session.get(url)
-            soup = BeautifulSoup(req.text, 'lxml')
-            posts = soup.find('section').findAll('article', recursive=False)
-            for post in posts:
-                data = json.loads(post.get('data-ft'))
-                post_id = data['mf_story_key']
-                posts_id.append(post_id)
-                if len(posts_id) >= num:
-                    break
-            if len(posts_id) >= num:
-                    break
-            next_href = soup.find('div', id='recent').next_sibling.find('a').get('href')
-            url = 'https://mbasic.facebook.com' + next_href
-        return posts_id
+                yield post_id
+            next_page_link = soup.find('section').next_sibling.find('a')
+            if next_page_link:
+                next_href = next_page_link.get('href')
+                url = 'https://mbasic.facebook.com' + next_href
+            else:
+                break
 
-    def post(self, 
-             content, 
+    def get_fanpage_post_list(self, fanpage_id):
+        if not self.login_check:
+            logging.error('You should login first')
+            return
+        url = 'https://m.facebook.com/page_content_list_view/more/?' + \
+              'page_id=46251501064&start_cursor=%7B%22timeline_cursor%22%3Anull%2C%22timeline_section_cursor%22%3Anull%2C%22' + \
+              'has_next_page%22%3Atrue%7D&num_to_fetch=4&surface_type=timeline'
+
+        while True:
+            req = self.session.post(url, data={'fb_dtsg': self.fb_dtsg})
+            text = req.text
+            text = req.text.encode().decode("unicode-escape")
+            text = text.encode('utf-16', 'surrogatepass').decode('utf-16')
+            text = text.replace('\/', '/')
+            soup = BeautifulSoup(text, 'lxml')
+            articles = soup.findAll('article')
+            for article in articles:
+                if article.get('data-ft'):
+                    data = json.loads(article.get('data-ft'))
+                    post_id = data['mf_story_key']
+                    yield post_id
+            next_page_div = soup.find('div', id='see_more_cards_id')
+            if not next_page_div:
+                break
+            next_href = next_page_div.find('a').get('href')
+            url = 'https://m.facebook.com' + next_href
+
+    def post(self,
+             content,
              privacy_level=privacy_level.PUBLIC):
         if not self.login_check:
             logging.error('You should login first')
@@ -282,7 +290,8 @@ class API:
             logging.error('You should login first')
             return
         post_data = self.post_data_template
-        url = 'https://mbasic.facebook.com/composer/mbasic/?av=%s'%str(fanpage_id)
+        url = 'https://mbasic.facebook.com/composer/mbasic/?av=%s' % str(
+            fanpage_id)
         post_data['xc_message'] = content
         post_data['referrer'] = 'pages_feed'
         post_data['c_src'] = 'page_self'
@@ -291,26 +300,27 @@ class API:
 
     def fanpage_post_photo(self, text_content, image, fanpage_id):
         url = 'https://mbasic.facebook.com/composer/mbasic/' + \
-                        '?c_src=page_self&referrer=pages_feed&' + \
-                        'target=%s&'%fanpage_id + \
-                        'icv=lgc_view_photo&av=%s'%fanpage_id
+            '?c_src=page_self&referrer=pages_feed&' + \
+            'target=%s&' % fanpage_id + \
+            'icv=lgc_view_photo&av=%s' % fanpage_id
         req = self.session.get(url)
-        soup = BeautifulSoup(req.text,'lxml')
+        soup = BeautifulSoup(req.text, 'lxml')
         form = soup.find('form')
         all_input_data = form.findAll('input')
         data = {}
         for input_data in all_input_data:
             data[input_data.get('name')] = input_data.get('value')
 
-        url = 'https://upload.facebook.com/_mupload_/composer/?av=%s'%fanpage_id
-        data['file1'] = ('image',image,'image')
+        url = 'https://upload.facebook.com/_mupload_/composer/?av=%s' % fanpage_id
+        data['file1'] = ('image', image, 'image')
         data['xc_message'] = text_content
         m_data = MultipartEncoder(
-                        fields = data
-                 )
-        self.session.post(url, data=m_data, headers={'Content-Type': m_data.content_type})
+            fields=data
+        )
+        self.session.post(url, data=m_data, headers={
+                          'Content-Type': m_data.content_type})
 
-    def group_sell_post(self, 
+    def group_sell_post(self,
                         group_id,
                         title, price,
                         location='',
@@ -326,32 +336,37 @@ class API:
         data['composer_attachment_sell_currency'] = currency
         data['target'] = str(group_id)
         for i, image in enumerate(images[:3]):
-            data['file%d'%i] = image
+            data['file%d' % i] = image
         data['xc_message'] = content
         m_data = MultipartEncoder(
-                        fields = data
-                )
-        self.session.post(url, data=m_data, headers={'Content-Type': m_data.content_type})
+            fields=data
+        )
+        self.session.post(url, data=m_data, headers={
+                          'Content-Type': m_data.content_type})
     # comment methods
+
     def get_comments(self, post_id, group_id=None, num=10, start=0):
         if not self.login_check:
             logging.error('You should login first')
             return
-        
+
         comment_info_list = []
         while num > 0:
             url = 'https://mbasic.facebook.com/story.php?' + \
-                'story_fbid=%s&id=1&p=%s'%(str(post_id),start)
+                'story_fbid=%s&id=1&p=%s' % (str(post_id), start)
             if group_id:
-                url = 'https://mbasic.facebook.com/groups/%s?view=permalink&id=%s'%(group_id, post_id)
+                url = 'https://mbasic.facebook.com/groups/%s?view=permalink&id=%s' % (
+                    group_id, post_id)
             req = self.session.get(url)
-            soup = BeautifulSoup(req.text,'lxml')
+            soup = BeautifulSoup(req.text, 'lxml')
             try:
-                div = soup.find('div',id='ufi_%s'%str(post_id))
-                comment_div = div.find('div',id='sentence_%s'%str(post_id)).next_sibling
+                div = soup.find('div', id='ufi_%s' % str(post_id))
+                comment_div = div.find(
+                    'div', id='sentence_%s' % str(post_id)).next_sibling
                 comments = comment_div.findAll('div', recursive=False)
                 if group_id and not comments:
-                    comments = comment_div.next_sibling.findAll('div', recursive=False)
+                    comments = comment_div.next_sibling.findAll(
+                        'div', recursive=False)
                 comments.reverse()
             except Exception as e:
                 logging.debug(e)
@@ -364,20 +379,21 @@ class API:
                     comment_content = comment.find('h3').next_sibling.text
                     comment_time = comment.find('abbr').text
                     comment_url = 'https://mbasic.facebook.com' + \
-                                  comment.find('span', id='like_%s_%s'%(post_id, comment_id)).\
+                                  comment.find('span', id='like_%s_%s' % (post_id, comment_id)).\
                                   next_sibling.next_sibling.get('href')
                     comment_info = data_type.CommentInfo(comment_id,
                                                          comment_author,
                                                          comment_content,
                                                          comment_time,
                                                          comment_url
-                                                        )
+                                                         )
                     comment_info_list.append(comment_info)
                     num -= 1
                 except Exception as e:
                     pass
 
-            pre_page_div = comment_div.find('div', id='see_prev_%s'%str(post_id))
+            pre_page_div = comment_div.find(
+                'div', id='see_prev_%s' % str(post_id))
 
             if pre_page_div:
                 pre_href = pre_page_div.find('a').get('href')
@@ -386,8 +402,6 @@ class API:
             else:
                 break
 
-
-
         return comment_info_list
 
     def delete_comment(self, post_id, comment_id):
@@ -395,28 +409,28 @@ class API:
             logging.error('You should login first')
             return
         url = 'https://mbasic.facebook.com/ufi/delete/?' + \
-              'delete_comment_id=%s'%str(comment_id) + \
-              '&delete_comment_fbid=%s'%str(comment_id) + \
-              '&ft_ent_identifier=%s'%str(post_id)
+              'delete_comment_id=%s' % str(comment_id) + \
+              '&delete_comment_fbid=%s' % str(comment_id) + \
+              '&ft_ent_identifier=%s' % str(post_id)
         data = {'fb_dtsg': self.fb_dtsg}
         return self.session.post(url, data=data)
 
     def comment(self, post_id, content):
         url = 'https://mbasic.facebook.com/a/comment.php?' + \
               'fs=8&actionsource=2&comment_logging' + \
-              '&ft_ent_identifier=%s'%str(post_id)
-        comment = {'comment_text':content,'fb_dtsg':self.fb_dtsg}
+              '&ft_ent_identifier=%s' % str(post_id)
+        comment = {'comment_text': content, 'fb_dtsg': self.fb_dtsg}
         return self.session.post(url, data=comment)
 
     # reply method
-    def reply(self, post_id ,comment_id, content):
+    def reply(self, post_id, comment_id, content):
         if not self.login_check:
             logging.error('You should login first')
             return
         url = 'https://mbasic.facebook.com/a/comment.php?' + \
-              'parent_comment_id=%s'%str(comment_id) + \
-              '&ft_ent_identifier=%s'%str(post_id)
-        data = {'fb_dtsg': self.fb_dtsg, 'comment_text':content}
+              'parent_comment_id=%s' % str(comment_id) + \
+              '&ft_ent_identifier=%s' % str(post_id)
+        data = {'fb_dtsg': self.fb_dtsg, 'comment_text': content}
         self.session.post(url, data=data)
 
     def get_replies(self, post_id, comment_id, group_id=None, num=10):
@@ -429,7 +443,7 @@ class API:
         reply_info_list = []
         while num > 0:
             req = self.session.get(url)
-            soup = BeautifulSoup(req.text,'lxml')
+            soup = BeautifulSoup(req.text, 'lxml')
             try:
                 soup = BeautifulSoup(req.text, 'lxml')
                 replies_div = soup.find('div', id=str(comment_id)).next_sibling
@@ -449,12 +463,13 @@ class API:
                                                      reply_author,
                                                      reply_content,
                                                      reply_time,
-                                                    )
+                                                     )
                     reply_info_list.append(reply_info)
                     num -= 1
                 except Exception:
                     pass
-            pre_page_div = soup.find('div', id='comment_replies_more_1:%s_%s'%(str(post_id),str(comment_id)))
+            pre_page_div = soup.find(
+                'div', id='comment_replies_more_1:%s_%s' % (str(post_id), str(comment_id)))
 
             if pre_page_div:
                 pre_href = pre_page_div.find('a').get('href')
@@ -463,13 +478,14 @@ class API:
                 break
         return reply_info_list
 
-
     # messenger method
+
     def get_msg(self, chat_room_id, num=1):
         if not self.login_check:
             logging.error('You should login first')
             return
-        url = 'https://mbasic.facebook.com/messages/read/?tid=%s'%str(chat_room_id)
+        url = 'https://mbasic.facebook.com/messages/read/?tid=%s' % str(
+            chat_room_id)
         send_from = []
         content = []
         time = []
@@ -481,15 +497,16 @@ class API:
                 index = 0
             else:
                 index = 1
-            
-            msgs = msg_group.findAll('div', recursive=False)[index].findAll('div', recursive=False)
+
+            msgs = msg_group.findAll('div', recursive=False)[
+                index].findAll('div', recursive=False)
             if msgs:
                 msgs.reverse()
             for msg in msgs:
                 content_class = letter_adder(msg.get('class')[-1], 1)
                 try:
                     msg_contents = msg.find('div', class_=content_class). \
-                                                        find('div').findAll('span')
+                        find('div').findAll('span')
                     for msg_content in msg_contents:
                         send_from.append(msg.find('strong').text)
                         content.append(msg_content.text)
@@ -517,7 +534,8 @@ class API:
         url = 'https://mbasic.facebook.com/messages/?folder=unread'
         req = self.session.get(url)
         soup = BeautifulSoup(req.text, 'lxml')
-        unread_chats = soup.find('div', id='root').find('section').findAll('table')
+        unread_chats = soup.find('div', id='root').find(
+            'section').findAll('table')
         unread_chat_room_id = []
         for unread_chat in unread_chats:
             href = unread_chat.find('a').get('href')
@@ -528,7 +546,7 @@ class API:
             else:
                 chat_room_id = href[href.find('cid.g.')+6:href.find('&')]
             unread_chat_room_id.append(chat_room_id)
-        
+
         return unread_chat_room_id
 
     def send_msg(self, chat_room_id, content):
@@ -537,10 +555,11 @@ class API:
             return
         url = 'https://mbasic.facebook.com/messages/send/'
         if len(str(chat_room_id)) > len(self.user_id):
-            self.send_msg_data['tids'] = 'cid.g.%s'%str(chat_room_id)
+            self.send_msg_data['tids'] = 'cid.g.%s' % str(chat_room_id)
         else:
-            self.send_msg_data['tids'] = '%s'%str(chat_room_id)
-            self.send_msg_data['ids[%s]'%str(chat_room_id)] = str(chat_room_id)
+            self.send_msg_data['tids'] = '%s' % str(chat_room_id)
+            self.send_msg_data['ids[%s]' %
+                               str(chat_room_id)] = str(chat_room_id)
         self.send_msg_data['body'] = content
         self.session.post(url, data=self.send_msg_data)
 
@@ -548,15 +567,16 @@ class API:
         url = 'https://upload.facebook.com/_mupload_/mbasic/messages/attachment/photo/'
         send_data = self.send_msg_data.copy()
         if len(str(chat_room_id)) > len(self.user_id):
-            send_data['tids'] = 'cid.g.%s'%str(chat_room_id)
+            send_data['tids'] = 'cid.g.%s' % str(chat_room_id)
         else:
-            send_data['tids'] = '%s'%str(chat_room_id)
-            send_data['ids[%s]'%str(chat_room_id)] = str(chat_room_id)
-        send_data['tids'] = 'cid.g.%s'%str(chat_room_id)
-        send_data['file1'] = ('image',image,'image')
+            send_data['tids'] = '%s' % str(chat_room_id)
+            send_data['ids[%s]' % str(chat_room_id)] = str(chat_room_id)
+        send_data['tids'] = 'cid.g.%s' % str(chat_room_id)
+        send_data['file1'] = ('image', image, 'image')
         send_data['body'] = content
 
         m_data = MultipartEncoder(
-                        fields = send_data
-                 )
-        self.session.post(url, data=m_data, headers={'Content-Type': m_data.content_type})
\ No newline at end of file
+            fields=send_data
+        )
+        self.session.post(url, data=m_data, headers={
+                          'Content-Type': m_data.content_type})
